encode_stream

Function encode_stream 

pub fn encode_stream<S>(
    headers: &mut HeaderMap,
    body: S,
    coding: Coding,
) -> Result<RequestStream>
where S: Stream<Item = Result<Bytes>> + Send + 'static,
Compress a streaming request body in coding, and declare it in the headers.

As encode, for a body arriving in chunks. It goes out chunked, having no length to declare.