Module response

Module response 

Deciding and applying the decoding of a response body.

Structs

AcceptEncoding
What a request’s Accept-Encoding accepts.

Constants

DEFAULT_ACCEPT_ENCODING
The Accept-Encoding Faith advertises when the caller advertises none.

Functions

decode
Decode one layer of a response body, and update its headers to match.
decode_stream
Wrap a body byte-stream in a decoder for coding.

Type Aliases

ByteStream
A body byte-stream, as the decoders take and return one.